# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/prediction_log.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto import log_key_pb2 as proto_dot_log__key__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/prediction_log.proto',
  package='bunniebroker',
  syntax='proto3',
  serialized_pb=_b('\n\x1aproto/prediction_log.proto\x12\x0c\x62unniebroker\x1a\x13proto/log_key.proto\"\xe7\x01\n\rPredictionLog\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x14.bunniebroker.LogKey\x12\x18\n\x10\x63urrent_timeslot\x18\x02 \x01(\x05\x12\x1b\n\x13prediction_timeslot\x18\x03 \x01(\x05\x12%\n\x1dtariff_market_consumption_mwh\x18\x04 \x01(\x01\x12*\n\"tariff_market_solar_production_mwh\x18\x05 \x01(\x01\x12)\n!tariff_market_wind_production_mwh\x18\x06 \x01(\x01\x42\x1a\n\x16\x63om.bunniebroker.protoP\x01\x62\x06proto3')
  ,
  dependencies=[proto_dot_log__key__pb2.DESCRIPTOR,])




_PREDICTIONLOG = _descriptor.Descriptor(
  name='PredictionLog',
  full_name='bunniebroker.PredictionLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bunniebroker.PredictionLog.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_timeslot', full_name='bunniebroker.PredictionLog.current_timeslot', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prediction_timeslot', full_name='bunniebroker.PredictionLog.prediction_timeslot', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tariff_market_consumption_mwh', full_name='bunniebroker.PredictionLog.tariff_market_consumption_mwh', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tariff_market_solar_production_mwh', full_name='bunniebroker.PredictionLog.tariff_market_solar_production_mwh', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tariff_market_wind_production_mwh', full_name='bunniebroker.PredictionLog.tariff_market_wind_production_mwh', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=297,
)

_PREDICTIONLOG.fields_by_name['key'].message_type = proto_dot_log__key__pb2._LOGKEY
DESCRIPTOR.message_types_by_name['PredictionLog'] = _PREDICTIONLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictionLog = _reflection.GeneratedProtocolMessageType('PredictionLog', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTIONLOG,
  __module__ = 'proto.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:bunniebroker.PredictionLog)
  ))
_sym_db.RegisterMessage(PredictionLog)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\026com.bunniebroker.protoP\001'))
try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
